<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-revisions?lang_cible=sk
// ** ne pas modifier le fichier **

return [

	// R
	'revisions_description' => 'Sledujte zmeny redakčných objektov',
	'revisions_slogan' => 'Sledovanie zmien redakčných objektov',
];
